
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "autoar-enum-types.h"
/* enumerations from "autoar-extractor.h" */
#include "autoar-extractor.h"
GType
autoar_conflict_action_get_type (void)
{
  static GType type = 0;
  if (G_UNLIKELY (!type))
  {
    static const GEnumValue values[] = {
      { AUTOAR_CONFLICT_UNHANDLED,
        "AUTOAR_CONFLICT_UNHANDLED",
        "unhandled" },
      { AUTOAR_CONFLICT_SKIP,
        "AUTOAR_CONFLICT_SKIP",
        "skip" },
      { AUTOAR_CONFLICT_OVERWRITE,
        "AUTOAR_CONFLICT_OVERWRITE",
        "overwrite" },
      { AUTOAR_CONFLICT_CHANGE_DESTINATION,
        "AUTOAR_CONFLICT_CHANGE_DESTINATION",
        "change-destination" },
      { 0, NULL, NULL }
    };
    type = g_enum_register_static ("AutoarConflictAction", values);
  }
  return type;
}
/* enumerations from "autoar-format-filter.h" */
#include "autoar-format-filter.h"
GType
autoar_format_get_type (void)
{
  static GType type = 0;
  if (G_UNLIKELY (!type))
  {
    static const GEnumValue values[] = {
      { AUTOAR_FORMAT_ZIP,
        "AUTOAR_FORMAT_ZIP",
        "zip" },
      { AUTOAR_FORMAT_TAR,
        "AUTOAR_FORMAT_TAR",
        "tar" },
      { AUTOAR_FORMAT_CPIO,
        "AUTOAR_FORMAT_CPIO",
        "cpio" },
      { AUTOAR_FORMAT_7ZIP,
        "AUTOAR_FORMAT_7ZIP",
        "7zip" },
      { AUTOAR_FORMAT_AR_BSD,
        "AUTOAR_FORMAT_AR_BSD",
        "ar-bsd" },
      { AUTOAR_FORMAT_AR_SVR4,
        "AUTOAR_FORMAT_AR_SVR4",
        "ar-svr4" },
      { AUTOAR_FORMAT_CPIO_NEWC,
        "AUTOAR_FORMAT_CPIO_NEWC",
        "cpio-newc" },
      { AUTOAR_FORMAT_GNUTAR,
        "AUTOAR_FORMAT_GNUTAR",
        "gnutar" },
      { AUTOAR_FORMAT_ISO9660,
        "AUTOAR_FORMAT_ISO9660",
        "iso9660" },
      { AUTOAR_FORMAT_PAX,
        "AUTOAR_FORMAT_PAX",
        "pax" },
      { AUTOAR_FORMAT_USTAR,
        "AUTOAR_FORMAT_USTAR",
        "ustar" },
      { AUTOAR_FORMAT_XAR,
        "AUTOAR_FORMAT_XAR",
        "xar" },
      { 0, NULL, NULL }
    };
    type = g_enum_register_static ("AutoarFormat", values);
  }
  return type;
}
GType
autoar_filter_get_type (void)
{
  static GType type = 0;
  if (G_UNLIKELY (!type))
  {
    static const GEnumValue values[] = {
      { AUTOAR_FILTER_NONE,
        "AUTOAR_FILTER_NONE",
        "none" },
      { AUTOAR_FILTER_COMPRESS,
        "AUTOAR_FILTER_COMPRESS",
        "compress" },
      { AUTOAR_FILTER_GZIP,
        "AUTOAR_FILTER_GZIP",
        "gzip" },
      { AUTOAR_FILTER_BZIP2,
        "AUTOAR_FILTER_BZIP2",
        "bzip2" },
      { AUTOAR_FILTER_XZ,
        "AUTOAR_FILTER_XZ",
        "xz" },
      { AUTOAR_FILTER_LZMA,
        "AUTOAR_FILTER_LZMA",
        "lzma" },
      { AUTOAR_FILTER_LZIP,
        "AUTOAR_FILTER_LZIP",
        "lzip" },
      { AUTOAR_FILTER_LZOP,
        "AUTOAR_FILTER_LZOP",
        "lzop" },
      { AUTOAR_FILTER_GRZIP,
        "AUTOAR_FILTER_GRZIP",
        "grzip" },
      { AUTOAR_FILTER_LRZIP,
        "AUTOAR_FILTER_LRZIP",
        "lrzip" },
      { AUTOAR_FILTER_ZSTD,
        "AUTOAR_FILTER_ZSTD",
        "zstd" },
      { 0, NULL, NULL }
    };
    type = g_enum_register_static ("AutoarFilter", values);
  }
  return type;
}

/* Generated data ends here */

